import 'package:flutter/material.dart';
import 'package:flutter_workshop/views/components/sidebar.dart';
import 'package:flutter_workshop/views/home/accounting.dart';
import 'package:flutter_workshop/views/home/setting.dart';

final List<Widget> pages = [const AccountingApp(), const SettingApp()];

class HomeViewScreen extends StatelessWidget {
  const HomeViewScreen(
      {super.key,
      this.email = "-",
      this.selectedIndex = 0,
      this.onDestination,
      this.onLogout
      });

  final String email;
  final int selectedIndex;
  final void Function(int)? onDestination;
  final void Function()? onLogout;

  List<Widget> _renderAppbarAction() => [
        PopupMenuButton(
          onSelected: (value) {
            if(value == "logout" && onLogout != null){
              onLogout!();
            }
          },
          offset: const Offset(10, 50),
          itemBuilder: ((context) => const [
                PopupMenuItem(value: "logout", child: Text("ออกจากระบบ"))
              ]),
          child: Row(
            children: [
              const Icon(Icons.person),
              Text(email),
            ],
          ))
      ];

  @override
  Widget build(BuildContext context) {
    return Scaffold(
        appBar: AppBar(
          backgroundColor: Theme.of(context).colorScheme.inversePrimary,
          leading: const Icon(Icons.home_filled),
          centerTitle: false,
          title: const Text("Flutter Workshop"),
          actions: _renderAppbarAction(),
        ),
        body: Row(
          crossAxisAlignment: CrossAxisAlignment.start,
          mainAxisAlignment: MainAxisAlignment.start,
          children: [
            AppSidebar(
              selectedIndex: selectedIndex,
              onDestination: onDestination,
            ),
            Expanded(
                child: Container(
              child: pages[selectedIndex],
            ))
          ],
        ));
  }
}
